import type { PropType, ExtractPropTypes, VNode } from 'vue';
import type { VueNode } from '@ant-design-vue/pro-utils';
import type { Options } from 'scroll-into-view-if-needed';
import type BaseFrom from './BaseForm';
import type { SubmitterProps } from './components/Submitter/types';
import { type Recordable } from '../typings';
/** baseForm基础props */
export declare const commonFormProps: {
    /**提交失败自动滚动到第一个错误字段 */
    scrollToFirstError: {
        type: PropType<boolean | Options<any> | undefined>;
    };
    submitter: {
        type: PropType<boolean | (Partial<ExtractPropTypes<{
            onSubmit: {
                type: PropType<(value?: any) => void>;
            };
            onReset: {
                type: PropType<(value?: any) => void>;
            };
            searchConfig: {
                type: PropType<{
                    submitText?: string | undefined;
                    resetText?: string | undefined;
                }>;
            };
            submitButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>;
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>; /**表单提交 */
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
            resetButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>;
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>; /**表单提交 */
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
        }>> & {
            render?: false | ((props: SubmitterProps & {
                submit: () => void;
                reset: () => void;
            }, dom: VueNode) => VueNode) | undefined;
        })>;
    };
    /**
     *  @name 是否只读模式，对所有表单项生效
     *  @description 优先低于表单项的 readonly
     */
    readonly: {
        type: PropType<boolean>;
    };
    /**
     * 是否重置之后重新请求数据
     */
    submitOnReset: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**表单提交 */
    onFinish: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    /**表单提交 */
    onSubmit: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    /**重置表单 */
    onReset: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    grid: {
        type: PropType<boolean>;
    };
    colProps: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>>>;
    };
    rowProps: {
        type: PropType<Partial<ExtractPropTypes<{
            align: PropType<"stretch" | "bottom" | "top" | "middle">;
            justify: PropType<"space-around" | "space-between" | "center" | "end" | "start">;
            prefixCls: StringConstructor;
            gutter: {
                type: PropType<import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter]>;
                default: import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter];
            };
            wrap: {
                type: BooleanConstructor;
                default: any;
            };
        }>>>;
    };
    layout: import("vue-types").VueTypeDef<"inline" | "horizontal" | "vertical">;
    labelCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>; /**
                 * 是否重置之后重新请求数据
                 */
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    wrapperCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    colon: {
        type: BooleanConstructor;
        default: any;
    };
    labelAlign: import("vue-types").VueTypeDef<"left" | "right">;
    labelWrap: {
        type: BooleanConstructor;
        default: any;
    };
    prefixCls: StringConstructor;
    requiredMark: {
        type: PropType<"" | import("ant-design-vue/es/form/Form").RequiredMark>;
        default: any;
    };
    hideRequiredMark: {
        type: BooleanConstructor;
        default: any;
    };
    model: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    rules: {
        type: PropType<{
            [k: string]: import("ant-design-vue/es/form").RuleObject | import("ant-design-vue/es/form").RuleObject[];
        }>;
    };
    validateMessages: {
        type: PropType<import("ant-design-vue/es/form/interface").ValidateMessages>;
        default: import("ant-design-vue/es/form/interface").ValidateMessages;
    };
    validateOnRuleChange: {
        type: BooleanConstructor;
        default: any;
    };
    name: StringConstructor;
    validateTrigger: {
        type: PropType<string | string[]>;
    };
    size: {
        type: PropType<import("ant-design-vue/es/button").ButtonSize>;
    };
    onValuesChange: {
        type: PropType<(changedValues: any, values: any) => void>;
    };
    onFieldsChange: {
        type: PropType<(changedFields: import("ant-design-vue/es/form/interface").FieldData[], allFields: import("ant-design-vue/es/form/interface").FieldData[]) => void>;
    };
    onFinishFailed: {
        type: PropType<(errorInfo: import("ant-design-vue/es/form/interface").ValidateErrorEntity<any>) => void>;
    };
    onValidate: {
        type: PropType<(name: string | number | string[] | number[], status: boolean, errors: string[]) => void>;
    };
    form: StringConstructor;
};
export declare const baseFormProps: {
    contentRender: {
        type: PropType<(items: VueNode[], submitter: VNode<SubmitterProps> | undefined) => VueNode>;
    };
    /**提交失败自动滚动到第一个错误字段 */
    scrollToFirstError: {
        type: PropType<boolean | Options<any> | undefined>;
    };
    submitter: {
        type: PropType<boolean | (Partial<ExtractPropTypes<{
            onSubmit: {
                type: PropType<(value?: any) => void>;
            };
            onReset: {
                type: PropType<(value?: any) => void>;
            };
            searchConfig: {
                type: PropType<{
                    submitText?: string | undefined;
                    resetText?: string | undefined;
                }>;
            };
            submitButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>;
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>; /**表单提交 */
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
            resetButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>;
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>; /**表单提交 */
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
        }>> & {
            render?: false | ((props: SubmitterProps & {
                submit: () => void;
                reset: () => void;
            }, dom: VueNode) => VueNode) | undefined;
        })>;
    };
    /**
     *  @name 是否只读模式，对所有表单项生效
     *  @description 优先低于表单项的 readonly
     */
    readonly: {
        type: PropType<boolean>;
    };
    /**
     * 是否重置之后重新请求数据
     */
    submitOnReset: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**表单提交 */
    onFinish: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    /**表单提交 */
    onSubmit: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    /**重置表单 */
    onReset: {
        type: PropType<(fromModel: Recordable<any>) => void>;
    };
    grid: {
        type: PropType<boolean>;
    };
    colProps: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>>>;
    };
    rowProps: {
        type: PropType<Partial<ExtractPropTypes<{
            align: PropType<"stretch" | "bottom" | "top" | "middle">;
            justify: PropType<"space-around" | "space-between" | "center" | "end" | "start">;
            prefixCls: StringConstructor;
            gutter: {
                type: PropType<import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter]>;
                default: import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter];
            };
            wrap: {
                type: BooleanConstructor;
                default: any;
            };
        }>>>;
    };
    layout: import("vue-types").VueTypeDef<"inline" | "horizontal" | "vertical">;
    labelCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>; /**
                 * 是否重置之后重新请求数据
                 */
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    wrapperCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    colon: {
        type: BooleanConstructor;
        default: any;
    };
    labelAlign: import("vue-types").VueTypeDef<"left" | "right">;
    labelWrap: {
        type: BooleanConstructor;
        default: any;
    };
    prefixCls: StringConstructor;
    requiredMark: {
        type: PropType<"" | import("ant-design-vue/es/form/Form").RequiredMark>;
        default: any;
    };
    hideRequiredMark: {
        type: BooleanConstructor;
        default: any;
    };
    model: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    rules: {
        type: PropType<{
            [k: string]: import("ant-design-vue/es/form").RuleObject | import("ant-design-vue/es/form").RuleObject[];
        }>;
    };
    validateMessages: {
        type: PropType<import("ant-design-vue/es/form/interface").ValidateMessages>;
        default: import("ant-design-vue/es/form/interface").ValidateMessages;
    };
    validateOnRuleChange: {
        type: BooleanConstructor;
        default: any;
    };
    name: StringConstructor;
    validateTrigger: {
        type: PropType<string | string[]>;
    };
    size: {
        type: PropType<import("ant-design-vue/es/button").ButtonSize>;
    };
    onValuesChange: {
        type: PropType<(changedValues: any, values: any) => void>;
    };
    onFieldsChange: {
        type: PropType<(changedFields: import("ant-design-vue/es/form/interface").FieldData[], allFields: import("ant-design-vue/es/form/interface").FieldData[]) => void>;
    };
    onFinishFailed: {
        type: PropType<(errorInfo: import("ant-design-vue/es/form/interface").ValidateErrorEntity<any>) => void>;
    };
    onValidate: {
        type: PropType<(name: string | number | string[] | number[], status: boolean, errors: string[]) => void>;
    };
    form: StringConstructor;
};
export declare const baseFormEmit: {
    finish: (values: Recordable<any>) => boolean;
    submit: (values: Recordable<any>) => boolean;
    valuesChange: (values: Recordable<any>) => boolean;
};
export declare type BaseFormEmit = typeof baseFormEmit;
export declare type CommonFormProps = Partial<ExtractPropTypes<typeof commonFormProps>>;
export declare type BaseFormPropsType = Partial<ExtractPropTypes<typeof baseFormProps>>;
export declare type BaseFromInstance = InstanceType<typeof BaseFrom>;
