import type { ExtractPropTypes, PropType } from 'vue';
import type { CSSProperties } from '@vue/runtime-dom';
import type { default as QueryFilter } from './QuertFilter';
import type { SpanConfig } from './components/form-action/utils/span-config';
export declare const baseFormPropsKeys: string[];
export declare const queryFilterProps: {
    /**表单布局 */
    layout: {
        type: PropType<"inline" | "horizontal" | "vertical" | undefined>;
        default: string;
    };
    /**
     * @name 查询表单栅格间隔
     *
     * @example searchGutter={24}
     * */
    searchGutter: {
        type: PropType<import("ant-design-vue/lib/grid/Row").Gutter | [import("ant-design-vue/lib/grid/Row").Gutter, import("ant-design-vue/lib/grid/Row").Gutter] | undefined>;
        default: number;
    };
    /** 自定义样式 */
    style: {
        type: PropType<CSSProperties>;
    };
    /**
     * @name 配置列数，一般而言是 8 的倍数
     *
     * @example 配置一行4个
     * span={6}
     *
     * @example 配置一行3个
     * span={6}
     *
     * @example 根据屏幕宽度配置
     * span={xs: 24, sm: 12, md: 8, lg: 6, xl: 6, xxl: 6}
     * */
    span: {
        type: PropType<SpanConfig>;
    };
    /**自定义折叠状态下默认显示的表单控件数量，没有设置或小于 0，则显示一行控件; 数量大于等于控件数量则隐藏展开按钮 */
    defaultColsNumber: {
        type: PropType<number>;
        default: undefined;
    };
    /** 是否折叠超出的表单项，用于受控模式*/
    collapsed: {
        type: PropType<boolean>;
        default: undefined;
    };
    /**默认状态下是否折叠超出的表单项 */
    defaultCollapsed: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**是否能够查询收起的数据，如果设置为 false，收起后的表单数据将会丢失 */
    preserve: {
        type: PropType<boolean>;
        default: boolean;
    };
    /**
     * @name 每一行之前要不要有分割线
     * @description 只有在 `layout` 为 `vertical` 时生效
     */
    split: {
        type: PropType<boolean>;
        default: undefined;
    };
    /** 提交按钮的props*/
    submitButtonProps: {
        type: PropType<Partial<ExtractPropTypes<{
            prefixCls: StringConstructor;
            type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
            htmlType: {
                type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                default: string;
            };
            shape: {
                type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
            };
            size: {
                type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
            };
            loading: {
                type: PropType<boolean | {
                    delay?: number | undefined;
                }>;
                default: () => boolean | {
                    delay?: number | undefined;
                };
            };
            disabled: {
                type: BooleanConstructor;
                default: any;
            };
            ghost: {
                type: BooleanConstructor;
                default: any;
            };
            block: {
                type: BooleanConstructor;
                default: any;
            };
            danger: {
                type: BooleanConstructor;
                default: any;
            };
            icon: import("vue-types").VueTypeValidableDef<any>;
            href: StringConstructor;
            target: StringConstructor;
            title: StringConstructor;
            onClick: {
                type: PropType<(event: MouseEvent) => void>;
            };
            onMousedown: {
                type: PropType<(event: MouseEvent) => void>;
            };
        }>>>;
    };
    /** 切换表单折叠状态时的回调*/
    onCollapsed: {
        type: PropType<(collapsed: boolean) => void>;
    };
    contentRender: {
        type: PropType<(items: import("@ant-design-vue/pro-utils").VueNode[], submitter: import("vue").VNode<Partial<ExtractPropTypes<{
            onSubmit: {
                type: PropType<(value?: any) => void>;
            };
            onReset: {
                type: PropType<(value?: any) => void>;
            };
            searchConfig: {
                type: PropType<{
                    submitText?: string | undefined;
                    resetText?: string | undefined;
                }>;
            };
            submitButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
            resetButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
        }>>, import("vue").RendererElement, {
            [key: string]: any;
        }> | undefined) => import("@ant-design-vue/pro-utils").VueNode>;
    };
    scrollToFirstError: {
        type: PropType<boolean | import("scroll-into-view-if-needed").Options<any> | undefined>;
    };
    submitter: {
        type: PropType<boolean | (Partial<ExtractPropTypes<{
            onSubmit: {
                type: PropType<(value?: any) => void>;
            };
            onReset: {
                type: PropType<(value?: any) => void>;
            };
            searchConfig: {
                type: PropType<{
                    submitText?: string | undefined;
                    resetText?: string | undefined;
                }>;
            };
            submitButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
            resetButtonProps: {
                type: PropType<false | (Partial<ExtractPropTypes<{
                    prefixCls: StringConstructor;
                    type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                    htmlType: {
                        type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                        default: string;
                    };
                    shape: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                    };
                    size: {
                        type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                    };
                    loading: {
                        type: PropType<boolean | {
                            delay?: number | undefined;
                        }>;
                        default: () => boolean | {
                            delay?: number | undefined;
                        };
                    };
                    disabled: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    ghost: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    block: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    danger: {
                        type: BooleanConstructor;
                        default: any;
                    };
                    icon: import("vue-types").VueTypeValidableDef<any>;
                    href: StringConstructor;
                    target: StringConstructor;
                    title: StringConstructor;
                    onClick: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                    onMousedown: {
                        type: PropType<(event: MouseEvent) => void>;
                    };
                }>> & {
                    preventDefault?: boolean | undefined;
                })>;
                default: boolean;
            };
        }>> & {
            render?: false | ((props: Partial<ExtractPropTypes<{
                onSubmit: {
                    type: PropType<(value?: any) => void>;
                };
                onReset: {
                    type: PropType<(value?: any) => void>;
                };
                searchConfig: {
                    type: PropType<{
                        submitText?: string | undefined;
                        resetText?: string | undefined;
                    }>;
                };
                submitButtonProps: {
                    type: PropType<false | (Partial<ExtractPropTypes<{
                        prefixCls: StringConstructor;
                        type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                        htmlType: {
                            type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                            default: string;
                        };
                        shape: {
                            type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                        };
                        size: {
                            type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                        };
                        loading: {
                            type: PropType<boolean | {
                                delay?: number | undefined;
                            }>;
                            default: () => boolean | {
                                delay?: number | undefined;
                            };
                        };
                        disabled: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        ghost: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        block: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        danger: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        icon: import("vue-types").VueTypeValidableDef<any>;
                        href: StringConstructor;
                        target: StringConstructor;
                        title: StringConstructor;
                        onClick: {
                            type: PropType<(event: MouseEvent) => void>;
                        };
                        onMousedown: {
                            type: PropType<(event: MouseEvent) => void>;
                        };
                    }>> & {
                        preventDefault?: boolean | undefined;
                    })>;
                    default: boolean;
                };
                resetButtonProps: {
                    type: PropType<false | (Partial<ExtractPropTypes<{
                        prefixCls: StringConstructor;
                        type: PropType<import("ant-design-vue/lib/button").ButtonType>; /**表单布局 */
                        htmlType: {
                            type: PropType<import("ant-design-vue/lib/button/buttonTypes").ButtonHTMLType>;
                            default: string;
                        };
                        shape: {
                            type: PropType<import("ant-design-vue/lib/button").ButtonShape>;
                        };
                        size: {
                            type: PropType<import("ant-design-vue/lib/button").ButtonSize>;
                        };
                        loading: {
                            type: PropType<boolean | {
                                delay?: number | undefined;
                            }>;
                            default: () => boolean | {
                                delay?: number | undefined;
                            };
                        };
                        disabled: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        ghost: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        block: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        danger: {
                            type: BooleanConstructor;
                            default: any;
                        };
                        icon: import("vue-types").VueTypeValidableDef<any>;
                        href: StringConstructor;
                        target: StringConstructor;
                        title: StringConstructor;
                        onClick: {
                            type: PropType<(event: MouseEvent) => void>;
                        };
                        onMousedown: {
                            type: PropType<(event: MouseEvent) => void>;
                        };
                    }>> & {
                        preventDefault?: boolean | undefined;
                    })>;
                    default: boolean;
                };
            }>> & {
                submit: () => void;
                reset: () => void;
            }, dom: import("@ant-design-vue/pro-utils").VueNode) => import("@ant-design-vue/pro-utils").VueNode) | undefined;
        })>;
    };
    readonly: {
        type: PropType<boolean>;
    };
    submitOnReset: {
        type: PropType<boolean>;
        default: boolean;
    };
    onFinish: {
        type: PropType<(fromModel: import("../typings").Recordable<any>) => void>;
    };
    onSubmit: {
        type: PropType<(fromModel: import("../typings").Recordable<any>) => void>;
    };
    onReset: {
        type: PropType<(fromModel: import("../typings").Recordable<any>) => void>;
    };
    grid: {
        type: PropType<boolean>;
    };
    colProps: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>>>;
    };
    rowProps: {
        type: PropType<Partial<ExtractPropTypes<{
            align: PropType<"stretch" | "bottom" | "top" | "middle">;
            justify: PropType<"space-around" | "space-between" | "center" | "end" | "start">;
            prefixCls: StringConstructor;
            gutter: {
                type: PropType<import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter]>;
                default: import("ant-design-vue/es/grid/Row").Gutter | [import("ant-design-vue/es/grid/Row").Gutter, import("ant-design-vue/es/grid/Row").Gutter];
            };
            wrap: {
                type: BooleanConstructor;
                default: any;
            };
        }>>>;
    };
    labelCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            }; /**
             * @name 每一行之前要不要有分割线
             * @description 只有在 `layout` 为 `vertical` 时生效
             */
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    wrapperCol: {
        type: PropType<Partial<ExtractPropTypes<{
            span: (StringConstructor | NumberConstructor)[];
            order: (StringConstructor | NumberConstructor)[];
            offset: (StringConstructor | NumberConstructor)[];
            push: (StringConstructor | NumberConstructor)[];
            pull: (StringConstructor | NumberConstructor)[];
            xs: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            sm: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            md: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            lg: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            xxxl: {
                type: PropType<string | number | import("ant-design-vue/es/grid").ColSize>;
                default: string | number | import("ant-design-vue/es/grid").ColSize;
            };
            prefixCls: StringConstructor;
            flex: (StringConstructor | NumberConstructor)[];
        }>> & import("vue").HTMLAttributes>;
    };
    colon: {
        type: BooleanConstructor;
        default: any;
    };
    labelAlign: import("vue-types").VueTypeDef<"left" | "right">;
    labelWrap: {
        type: BooleanConstructor;
        default: any;
    };
    prefixCls: StringConstructor;
    requiredMark: {
        type: PropType<"" | import("ant-design-vue/es/form/Form").RequiredMark>;
        default: any;
    };
    hideRequiredMark: {
        type: BooleanConstructor;
        default: any;
    };
    model: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    rules: {
        type: PropType<{
            [k: string]: import("ant-design-vue/es/form").RuleObject | import("ant-design-vue/es/form").RuleObject[];
        }>;
    };
    validateMessages: {
        type: PropType<import("ant-design-vue/es/form/interface").ValidateMessages>;
        default: import("ant-design-vue/es/form/interface").ValidateMessages;
    };
    validateOnRuleChange: {
        type: BooleanConstructor;
        default: any;
    };
    name: StringConstructor;
    validateTrigger: {
        type: PropType<string | string[]>;
    };
    size: {
        type: PropType<import("ant-design-vue/es/button").ButtonSize>;
    };
    onValuesChange: {
        type: PropType<(changedValues: any, values: any) => void>;
    };
    onFieldsChange: {
        type: PropType<(changedFields: import("ant-design-vue/es/form/interface").FieldData[], allFields: import("ant-design-vue/es/form/interface").FieldData[]) => void>;
    };
    onFinishFailed: {
        type: PropType<(errorInfo: import("ant-design-vue/es/form/interface").ValidateErrorEntity<any>) => void>;
    };
    onValidate: {
        type: PropType<(name: string | number | string[] | number[], status: boolean, errors: string[]) => void>;
    };
    form: StringConstructor;
};
export declare type QueryFilterProps = Partial<ExtractPropTypes<typeof queryFilterProps>>;
export declare type QueryFilternstance = InstanceType<typeof QueryFilter>;
